@@ -9,7 +9,7 @@
 
 __all__ = ["MokeError", "task", "stdin", "stdout", "stderr", "num", "doc",
            "INFO", "WARN", "ERROR"]
-__version__ = "1.1.0"
+__version__ = "1.1.1"
 
 
 import os
@@ -19,7 +19,7 @@ import logging
 from re import search
 from path import path
 from itertools import izip_longest
-from argparse import ArgumentParser, FileType
+from argparse import ArgumentParser, FileType, SUPPRESS
 from types import TypeType
 from types import FileType as BaseFileType
 from ConfigParser import SafeConfigParser
@@ -209,6 +209,8 @@ class task(object):
         main_parser.add_argument("-lf", type=str,
             default=__deflog__["lf"], choices=("tab",),
             help="(str) [default: %s] logging format" % __deflog__["lf"])
+
+
         
         # subcommand options
         sub_parsers = None
@@ -309,12 +311,26 @@ class task(object):
         params = " ".join(\
                 [str(tpl) for tpl in zip(names, vals)])
 
+
+        try:
+            # works on linux 3
+            stdin_name = os.readlink('/dev/fd/0')
+            stdout_name = os.readlink('/dev/fd/1')
+            stderr_name = os.readlink('/dev/fd/2')
+
+        except:
+            stdin_name,stdout_name,stderr_name = "","",""
+            
         # write logging header
         msgs = ("moke (version %s)" % __version__,
                 "cwd: \"%s\"" % cwd,
                 "mokefile: \"%s\"" % mokefile,
                 "task: %s" % func.func_name,
-                "params: %s" % params)
+                "params: %s" % params,
+                "stdin: %s" % stdin_name,
+                "stdout: %s" % stdout_name,
+                "stderr: %s" % stderr_name,
+        )
         for msg in msgs:
             lgr.info(msg)
         # final call, leaving moke
